
(function ($) {

Drupal.admin_pane = Drupal.admin_pane || {};

/**
 * Init administration pane.
 */
Drupal.behaviors.admin_pane = {
  attach: function(context) {
    // Toggle admin pane.
    $("#admin-pane-toggle", context).bind("click", function(e) {
      Drupal.admin_pane.toggle();
      return false;
    });

    // Activate tabs.
    $("#menu-tabs").tabs({ cookie: { expires: 30 } });

    // Respond to overlay loading.
    $(document).bind('drupalOverlayLoad', function(e) {
      Drupal.admin_pane.overlay(e);
    });

    // Respons to overlay closing.
    $(document).bind('drupalOverlayClose', function(e) {
      Drupal.admin_pane.overlay(e);
    });

    // Activate jsTree.
    $("#admin-pane .ui-tabs-panel").jstree({
      "core" : {
        "animation" : 0
      },
      "themes" : {
        "theme" : "classic",
        "icons" : false,
        "url" : Drupal.settings.basePath + Drupal.settings.admin_pane.path + "/jstree.css"
      },
      "plugins" : [ "themes", "html_data", "cookies" ]
    });

    $("#admin-pane a.hidden").click(function(){
      return false;
    }).css("cursor", "default");

    // Set the inital state of the admin pane.
    $('#admin-pane', context).once('admin-pane', Drupal.admin_pane.init);
  }
};

/**
 * Respond to overlay opening and closing.
 */
Drupal.admin_pane.overlay = function(e) {
  var $pane = $("#admin-pane > div");
  switch (e.type) {
    case 'drupalOverlayLoad':
      $pane.css('right', 15);
      break;

    case 'drupalOverlayClose':
      $pane.css('right', 0);
      break;
  }
}

/**
 * Retrieve last saved cookie settings and set up the initial admin pane state.
 */
Drupal.admin_pane.init = function() {
  // Retrieve the collapsed status for the toolbar from a stored cookie.
  var collapsed = $.cookie('Drupal.admin_pane.collapsed');

  // Expand or collapse the admin pane based on the cookie value.
  if (collapsed == 1) {
    Drupal.admin_pane.collapse();
  }
  else {
    Drupal.admin_pane.expand();
  }
};

/**
 * Collapse the admin pane.
 */
Drupal.admin_pane.collapse = function() {
  $.cookie("Drupal.admin_pane.collapsed", 1);
  $('#admin-pane').addClass('collapsed');
  $('body').removeClass('admin-pane').css('padding-right', 5);
  $("#admin-pane").css("right", -295);
};

/**
 * Expand the admin pane.
 */
Drupal.admin_pane.expand = function() {
  $.cookie("Drupal.admin_pane.collapsed", 0);
  $('#admin-pane').removeClass('collapsed');
  $('body').addClass('admin-pane').css('padding-right', 300);
  $("#admin-pane").css("right", 0);
};

/**
 * Toggle the admin pane.
 */
Drupal.admin_pane.toggle = function() {
  if ($('#admin-pane').hasClass('collapsed')) {
    Drupal.admin_pane.expand();
  }
  else {
    Drupal.admin_pane.collapse();
  }
};

})(jQuery);
